summaryrefslogtreecommitdiffstats
path: root/krfb
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:22:10 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:22:10 -0600
commit3e4d718796cddcc798d9f737037ef4bad540a0af (patch)
tree69d0aaad3f8f46c1dbb4939b7fcda8e7de12c481 /krfb
parent50d6569cdef5f0aac099f5d01864bd0e14f82ae3 (diff)
downloadtdenetwork-3e4d718796cddcc798d9f737037ef4bad540a0af.tar.gz
tdenetwork-3e4d718796cddcc798d9f737037ef4bad540a0af.zip
Rename KApplication to TDEApplication to avoid conflicts with KDE4
Diffstat (limited to 'krfb')
-rw-r--r--krfb/kcm_krfb/kcm_krfb.cpp2
-rw-r--r--krfb/krfb/configuration.cc4
-rw-r--r--krfb/krfb/invitation.cc4
-rw-r--r--krfb/krfb/main.cpp4
-rw-r--r--krfb/krfb/rfbcontroller.cc6
5 files changed, 10 insertions, 10 deletions
diff --git a/krfb/kcm_krfb/kcm_krfb.cpp b/krfb/kcm_krfb/kcm_krfb.cpp
index 0a29b0ed..ff3760e9 100644
--- a/krfb/kcm_krfb/kcm_krfb.cpp
+++ b/krfb/kcm_krfb/kcm_krfb.cpp
@@ -104,7 +104,7 @@ void KcmKRfb::checkKInetd(bool &kinetdAvailable, bool &krfbAvailable) {
kinetdAvailable = false;
krfbAvailable = false;
- DCOPClient *d = KApplication::dcopClient();
+ DCOPClient *d = TDEApplication::dcopClient();
TQByteArray sdata, rdata;
TQCString replyType;
diff --git a/krfb/krfb/configuration.cc b/krfb/krfb/configuration.cc
index 289c4cec..d78f7f92 100644
--- a/krfb/krfb/configuration.cc
+++ b/krfb/krfb/configuration.cc
@@ -51,7 +51,7 @@ Configuration::Configuration(krfb_mode mode) :
portNum(-1),
kinetdRef("kded", "kinetd")
{
- kinetdRef.setDCOPClient(KApplication::dcopClient());
+ kinetdRef.setDCOPClient(TDEApplication::dcopClient());
loadFromKConfig();
saveToDialogs();
doKinetdConf();
@@ -438,7 +438,7 @@ void Configuration::inviteEmail() {
save();
emit invitationNumChanged(invitationList.size());
- KApplication *app = KApplication::kApplication();
+ TDEApplication *app = TDEApplication::kApplication();
app->invokeMailer(TQString(), TQString(), TQString(),
i18n("Desktop Sharing (VNC) invitation"),
i18n("You have been invited to a VNC session. If you have the TDE Remote "
diff --git a/krfb/krfb/main.cpp b/krfb/krfb/main.cpp
index 6d21ee36..db730dcf 100644
--- a/krfb/krfb/main.cpp
+++ b/krfb/krfb/main.cpp
@@ -55,7 +55,7 @@ static KCmdLineOptions options[] =
void checkKInetd(bool &kinetdAvailable, bool &krfbAvailable) {
DCOPRef ref("kded", "kinetd");
- ref.setDCOPClient(KApplication::dcopClient());
+ ref.setDCOPClient(TDEApplication::dcopClient());
DCOPReply r = ref.call("isInstalled", TQString("krfb"));
if (!r.isValid()) {
@@ -101,7 +101,7 @@ int main(int argc, char *argv[])
TDECmdLineArgs::init(argc, argv, &aboutData);
TDECmdLineArgs::addCmdLineOptions(options);
- KApplication app;
+ TDEApplication app;
Configuration *config;
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
diff --git a/krfb/krfb/rfbcontroller.cc b/krfb/krfb/rfbcontroller.cc
index debe39f0..be384118 100644
--- a/krfb/krfb/rfbcontroller.cc
+++ b/krfb/krfb/rfbcontroller.cc
@@ -118,11 +118,11 @@ class AppLocker
{
public:
AppLocker() {
- KApplication::kApplication()->lock();
+ TDEApplication::kApplication()->lock();
}
~AppLocker() {
- KApplication::kApplication()->unlock();
+ TDEApplication::kApplication()->unlock();
}
};
@@ -560,7 +560,7 @@ void RFBController::disableBackground(bool state) {
disableBackgroundState = state;
DCOPRef ref("kdesktop", "KBackgroundIface");
- ref.setDCOPClient(KApplication::dcopClient());
+ ref.setDCOPClient(TDEApplication::dcopClient());
ref.send("setBackgroundEnabled(bool)", bool(!state));
}
diff --git a/krfb/krfb/invitation.cc b/krfb/krfb/invitation.cc
index e764036c..a41f9808 100644
--- a/krfb/krfb/invitation.cc
+++ b/krfb/krfb/invitation.cc
@@ -31,12 +31,12 @@ TQString cryptStr(const TQString &aStr) {
}
// a random string that doesn't contain i, I, o, O, 1, 0
// based on KApplication::randomString()
static TQString readableRandomString(int length) {
TQString str;
while (length)
{
- int r = KApplication::random() % 62;
+ int r = TDEApplication::random() % 62;
r += 48;
if (r > 57)
r += 7;
@@ -31,12 +31,12 @@ TQString cryptStr(const TQString &aStr) {
}
// a random string that doesn't contain i, I, o, O, 1, 0
-// based on KApplication::randomString()
+// based on TDEApplication::randomString()
static TQString readableRandomString(int length) {
TQString str;